CalibrationResult

Struct CalibrationResult 

pub struct CalibrationResult {
    pub tensor_params: Vec<(String, QuantizationParams)>,
    pub weight_params: Vec<(String, PerChannelQuantParams)>,
    pub method: Option<CalibrationMethod>,
}
Results from running the calibration pipeline on a module.

Fields

tensor_params: Vec<(String, QuantizationParams)>

Per-tensor quantization parameters, keyed by tensor name.

weight_params: Vec<(String, PerChannelQuantParams)>

Per-channel weight quantization parameters, keyed by weight name.

method: Option<CalibrationMethod>

The calibration method that was used.

Implementations

Source

impl CalibrationResult

pub fn find_tensor(&self, name: &str) -> Option<&QuantizationParams>

Look up per-tensor parameters by name.

pub fn find_weight(&self, name: &str) -> Option<&PerChannelQuantParams>

Look up per-channel parameters by name.

pub fn log_summary(&self)

Print a summary of calibration results to the log.